pub fn get_object(
fs: &impl Fs,
paths: &StorePaths,
doc_id: &str,
hash: &str,
) -> Result<Vec<u8>, SessionError>Expand description
Load and decompress the object addressed by hash for doc_id.
pub fn get_object(
fs: &impl Fs,
paths: &StorePaths,
doc_id: &str,
hash: &str,
) -> Result<Vec<u8>, SessionError>Load and decompress the object addressed by hash for doc_id.