pub fn version_content(
fs: &impl Fs,
paths: &StorePaths,
doc_id: &str,
version_id: &str,
) -> Result<Vec<u8>, SessionError>Expand description
The content of the version with the given id.
pub fn version_content(
fs: &impl Fs,
paths: &StorePaths,
doc_id: &str,
version_id: &str,
) -> Result<Vec<u8>, SessionError>The content of the version with the given id.