Object garbage collection.
Deletes content-addressed objects that are no longer referenced by the
Tier-1 session journal or the Tier-2 version history. An object is reachable
iff its hash appears as the snapshot of some live record in either manifest.
Structs
Functions
- gc
- Delete objects for
doc_idthat are not referenced by the Tier-1 journal or the Tier-2 versions. Safe to call any time; a no-op if there is no object dir.